Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS X-Ray.

Actions, resources, and condition keys for AWS X-Ray - Service Authorization Reference

# Actions, resources, and condition keys for AWS X-Ray

AWS X-Ray (service prefix: `xray` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS X-Ray
- Resource types defined by AWS X-Ray
- Condition keys for AWS X-Ray

## Actions defined by AWS X-Ray

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchGetTraceSummaryById [permission only] | Grants permission to retrieve metadata for a list of traces specified by ID | Read |  |  |
BatchGetTraces | Grants permission to retrieve a list of traces specified by ID. Each trace is a collection of segment documents that originates from a single request. Use GetTraceSummaries to get a list of trace IDs | List |  |  |
CreateGroup | Grants permission to create a group resource with a name and a filter expression | Write | group* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateSamplingRule | Grants permission to create a rule to control sampling behavior for instrumented applications | Write | sampling-rule* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteGroup | Grants permission to delete a group resource | Write | group* |  |
| aws:ResourceTag/${TagKey} |
DeleteResourcePolicy | Grants permission to delete resource policies | Write |  |  |
DeleteSamplingRule | Grants permission to delete a sampling rule | Write | sampling-rule* |  |
| aws:ResourceTag/${TagKey} |
GetDistinctTraceGraphs [permission only] | Grants permission to retrieve distinct service graphs for one or more specific trace IDs | Read |  |  |
GetEncryptionConfig | Grants permission to retrieve the current encryption configuration for X-Ray data | Read |  |  |
GetGroup | Grants permission to retrieve group resource details | Read | group* |  |
| aws:ResourceTag/${TagKey} |
GetGroups | Grants permission to retrieve all active group details | Read |  |  |
GetInsight | Grants permission to retrieve the details of a specific insight | Read |  |  |
GetInsightEvents | Grants permission to retrieve the events of a specific insight | Read |  |  |
GetInsightImpactGraph | Grants permission to retrieve the part of the service graph which is impacted for a specific insight | Read |  |  |
GetInsightSummaries | Grants permission to retrieve the summary of all insights for a group and time range with optional filters | Read |  |  |
GetSamplingRules | Grants permission to retrieve all sampling rules | Read |  |  |
GetSamplingStatisticSummaries | Grants permission to retrieve information about recent sampling results for all sampling rules | Read |  |  |
GetSamplingTargets | Grants permission to request a sampling quota for rules that the service is using to sample requests | Read |  |  |
GetServiceGraph | Grants permission to retrieve a document that describes services that process incoming requests, and downstream services that they call as a result | Read |  |  |
GetTimeSeriesServiceStatistics | Grants permission to retrieve an aggregation of service statistics defined by a specific time range bucketed into time intervals | Read |  |  |
GetTraceGraph | Grants permission to retrieve a service graph for one or more specific trace IDs | Read |  |  |
GetTraceSummaries | Grants permission to retrieve IDs and metadata for traces available for a specified time frame using an optional filter. To get the full traces, pass the trace IDs to BatchGetTraces | Read |  |  |
Link [permission only] | Grants permission to share X-Ray resources with a monitoring account | Write |  |  |
ListResourcePolicies | Grants permission to list resource policies | List |  |  |
ListTagsForResource | Grants permission to list tags for an X-Ray resource | List | group |  |
sampling-rule |  |
PutEncryptionConfig | Grants permission to update the encryption configuration for X-Ray data | Permissions management |  |  |
PutResourcePolicy | Grants permission to create or update resource policies | Write |  |  |
PutTelemetryRecords | Grants permission to send AWS X-Ray daemon telemetry to the service | Write |  |  |
PutTraceSegments | Grants permission to upload segment documents to AWS X-Ray. The X-Ray SDK generates segment documents and sends them to the X-Ray daemon, which uploads them in batches | Write |  |  |
TagResource | Grants permission to add tags to an X-Ray resource | Tagging | group |  |
sampling-rule |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove tags from an X-Ray resource | Tagging | group |  |
sampling-rule |  |
| aws:TagKeys |
UpdateGroup | Grants permission to update a group resource | Write | group* |  |
| aws:ResourceTag/${TagKey} |
UpdateSamplingRule | Grants permission to modify a sampling rule's configuration | Write | sampling-rule* |  |
| aws:ResourceTag/${TagKey} |

## Resource types defined by AWS X-Ray

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
group | `arn:$ { Partition}:xray:$ { Region}:$ { Account}:group/$ { GroupName}/$ { Id}` | aws:ResourceTag/${TagKey}
sampling-rule | `arn:$ { Partition}:xray:$ { Region}:$ { Account}:sampling-rule/$ { SamplingRuleName}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS X-Ray

AWS X-Ray defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.